@@ -387,6 +387,7 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 				ref : '../reminderNotificationsCheck'
 			}, {
 				xtype: 'zarafa.compositefield',
+				defaultMargins: '0 0 0 0',
 				plugins: [ 'zarafa.splitfieldlabeler' ],
 				fieldLabel: dgettext('plugin_desktopnotifications', '{A} Autohide desktop notification after second(s) {B}'),
 				labelWidth: 300,
@@ -399,7 +400,6 @@ Zarafa.plugins.desktopnotifications.js.settings.SettingsNotificationsWidget = Ex
 					boxLabel : '',
 					hideLabel : true,
 					checked : true,
-					style: 'margin-top: 4px',
 					listeners : {
 						change : this.onFieldChange,
 						scope : this
