@@ -49,14 +49,14 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 		$this->init_form();
 
 		// set backend description
-		$this->backendDescription = dgettext('plugin_filesbackendOwncloud', "With this backend, you can connect to any webdav server (e.g. ownCloud).");
+		$this->backendDescription = dgettext('plugin_filesbackendOwncloud', "With this backend, you can connect to any ownCloud server.");
 
 		// set backend display name
 		$this->backendDisplayName = "ownCloud";
 
 		// set backend version
 		// TODO: this should be changed on every release
-		$this->backendVersion = "1.0";
+		$this->backendVersion = "3.0";
 	}
 
 	/**
@@ -159,7 +159,9 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 		// check if curl is available
 		$serverHasCurl = function_exists('curl_version');
 		if (!$serverHasCurl) {
-			throw new BackendException($this->parseErrorCodeToMessage(self::WD_ERR_NO_CURL), 500);
+			$e = new BackendException($this->parseErrorCodeToMessage(self::WD_ERR_NO_CURL), 500);
+			$e->setTitle(dgettext('plugin_filesbackendOwncloud', 'php-curl is not available'));
+			throw $e;
 		}
 
 		$davsettings = array(
@@ -179,9 +181,13 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 		} catch (\Exception $e) {
 			$this->log('Failed to open: ' . $e->getMessage());
 			if (intval($e->getHTTPCode()) == 401) {
-				throw new BackendException($this->parseErrorCodeToMessage(self::WD_ERR_UNAUTHORIZED), $e->getHTTPCode());
+				$e = new BackendException($this->parseErrorCodeToMessage(self::WD_ERR_UNAUTHORIZED), $e->getHTTPCode());
+				$e->setTitle(dgettext('plugin_filesbackendOwncloud', 'Files ownCloud Backend: Access denied'));
+				throw $e;
 			} else {
-				throw new BackendException($this->parseErrorCodeToMessage(self::WD_ERR_UNREACHABLE), $e->getHTTPCode());
+				$e = new BackendException($this->parseErrorCodeToMessage(self::WD_ERR_UNREACHABLE), $e->getHTTPCode());
+				$e->setTitle(dgettext('plugin_filesbackendOwncloud', 'Files ownCloud Backend: Connection failed'));
+				throw $e;
 			}
 		}
 	}
@@ -231,10 +237,14 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 
 			return true;
 		} catch (ClientException $e) {
-			throw new BackendException($this->parseErrorCodeToMessage($e->getCode()), $e->getCode());
+			$e = new BackendException($this->parseErrorCodeToMessage($e->getCode()), $e->getCode());
+			$e->setTitle(dgettext('plugin_filesbackendOwncloud', 'Files ownCloud Backend: Sabre error'));
+			throw $e;
 		} catch (Exception $e) {
 			$this->log('[COPY] fatal: ' . $e->getMessage());
-			throw new BackendException($this->parseErrorCodeToMessage($e->getHTTPCode()), $e->getHTTPCode());
+			$e = new BackendException($this->parseErrorCodeToMessage($e->getHTTPCode()), $e->getHTTPCode());
+			$e->setTitle(dgettext('plugin_filesbackendOwncloud', 'Files ownCloud Backend: Copying failed'));
+			throw $e;
 		}
 	}
 
@@ -261,34 +271,35 @@ class Backend extends \Files\Backend\Webdav\Backend implements iFeatureSharing
 			case CURLE_COULDNT_CONNECT:
 			case CURLE_OPERATION_TIMEOUTED:
 			case self::WD_ERR_UNREACHABLE:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'File-server is not reachable. Wrong IP entered?');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'File server is not reachable. Please verify the file server URL.');
 				break;
 			case self::WD_ERR_FORBIDDEN:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'You don\'t have enough permissions for this operation.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'You don\'t have enough permissions to view this file or folder.');
 				break;
 			case self::WD_ERR_NOTFOUND:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'File is not available any more.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'The file or folder is not available anymore.');
 				break;
 			case self::WD_ERR_TIMEOUT:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'Connection to server timed out. Retry later.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'Connection to the file server timed out. Please check again later.');
 				break;
 			case self::WD_ERR_LOCKED:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'This file is locked by another user.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'This file is locked by another user. Please try again later.');
 				break;
 			case self::WD_ERR_FAILED_DEPENDENCY:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'The request failed due to failure of a previous request.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'The request failed due to failure of a previous request. Please contact your system administrator.');
 				break;
 			case self::WD_ERR_INTERNAL:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'File-server encountered a problem. Wrong IP entered?');
-				break; // this comes most likely from a wrong ip
+				// This is a general error, might be thrown due to a wrong IP, but we don't know.
+				$msg = dgettext('plugin_filesbackendOwncloud', 'The file server encountered an internal problem. Please contact your system administrator.');
+				break;
 			case self::WD_ERR_TMP:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'Could not write to temporary directory. Contact the server administrator.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'We could not write to temporary directory. Please contact your system administrator.');
 				break;
 			case self::WD_ERR_FEATURES:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'Could not retrieve list of server features. Contact the server administrator.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'We could not retrieve list of server features. Please contact the server administrator.');
 				break;
 			case self::WD_ERR_NO_CURL:
-				$msg = dgettext('plugin_filesbackendOwncloud', 'PHP-Curl is not available. Contact your system administrator.');
+				$msg = dgettext('plugin_filesbackendOwncloud', 'PHP-Curl is not available. Please contact your system administrator.');
 				break;
 		}
 
