@@ -121,7 +121,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 
 		// set backend version
 		// TODO: this should be changed on every release
-		$this->backendVersion = "0.1";
+		$this->backendVersion = "3.0";
 	}
 
 	/**
@@ -223,7 +223,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		} else {
 			// For backward compatibility we will check if the Encryption store exists. If not,
 			// we will fall back to the old way of retrieving the password from the session.
-			if ( class_exists('EncryptionStore') ) {
+			if (class_exists('EncryptionStore')) {
 				// Get the username and password from the Encryption store
 				$encryptionStore = \EncryptionStore::getInstance();
 				$this->set_user($encryptionStore->get('username'));
@@ -232,12 +232,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 				$this->set_user($GLOBALS['mapisession']->getUserName());
 				$password = $_SESSION['password']; 
 				if(function_exists('openssl_decrypt')) {
-					// In PHP 5.3.3 the iv parameter was added
-					if(version_compare(phpversion(), "5.3.3", "<")) {
-						$this->set_pass(openssl_decrypt($password, "des-ede3-cbc", PASSWORD_KEY, 0));
-					} else {
-						$this->set_pass(openssl_decrypt($password, "des-ede3-cbc", PASSWORD_KEY, 0, PASSWORD_IV));
-					}
+					$this->set_pass(openssl_decrypt($password, "des-ede3-cbc", PASSWORD_KEY, 0, PASSWORD_IV));
 				}
 			}
 		}
@@ -349,32 +344,39 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		try {
 			$this->smb_share = $server->getShare($this->share);
 		} catch (AccessDeniedException $e) {
-			$this->log("Access denied: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNAUTHORIZED), self::SMB_ERR_UNAUTHORIZED);
-
+			$this->log("AccessDeniedException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNAUTHORIZED), self::SMB_ERR_UNAUTHORIZED);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Access denied'));
+			throw $e;
 		} catch (ForbiddenException $e) {
-			$this->log("Forbidden: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNAUTHORIZED), self::SMB_ERR_UNAUTHORIZED);
-
+			$this->log("ForbiddenException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+			throw $e;
 		} catch (AuthenticationException $e) {
-			$this->log("Not authenticated: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNAUTHORIZED), self::SMB_ERR_UNAUTHORIZED);
-
+			$this->log("AuthenticationException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNAUTHORIZED), self::SMB_ERR_UNAUTHORIZED);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Authentication failed'));
+			throw $e;
 		} catch (TimedOutException $e) {
-			$this->log("Timeout: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNREACHABLE), self::SMB_ERR_UNREACHABLE);
-
+			$this->log("TimedOutException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNREACHABLE), self::SMB_ERR_UNREACHABLE);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Timeout'));
+			throw $e;
 		} catch (ConnectionRefusedException $e) {
-			$this->log("Refused: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNREACHABLE), self::SMB_ERR_UNREACHABLE);
-
+			$this->log("ConnectionRefusedException " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNREACHABLE), self::SMB_ERR_UNREACHABLE);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Connection refused'));
+			throw $e;
 		} catch (\Exception $e) {
 			// Something else failed...
-			$this->log("Opening failed: " . print_r($e, true));
-			throw new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+			$this->log("General exception, opening failed: " . print_r($e, true));
+			$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Connection failed'));
+			throw $e;
 		}
 
-		$this->log("SMB Share openened successfully!");
+		$this->log("SMB Share opened successfully");
 		return true;
 	}
 
@@ -397,17 +399,25 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		try {
 			$content = $this->smb_share->dir($dir);
 		} catch (ForbiddenException $e) {
-			$this->log("LS Forbidden: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNAUTHORIZED), self::SMB_ERR_UNAUTHORIZED);
+			$this->log("LS ForbiddenException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+			throw $e;
 		} catch (NotFoundException $e) {
-			$this->log("LS NFE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+			$this->log("LS NotFoundException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not found'));
+			throw $e;
 		} catch (InvalidTypeException $e) {
-			$this->log("LS ITE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
+			$this->log("LS InvalidTypeException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Invalid item type'));
+			throw $e;
 		} catch (\Exception $e) {
-			$this->log("LS failed: " . print_r($e, true));
-			throw new BackendException($e->getMessage(), self::SMB_ERR_NOTFOUND);
+			$this->log("LS General exception thrown, failed: " . print_r($e, true));
+			$e = new BackendException($e->getMessage(), self::SMB_ERR_NOTFOUND);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Failed to list items'));
+			throw $e;
 		}
 
 		foreach ($content as $record) {
@@ -450,17 +460,25 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		try {
 			$this->smb_share->mkdir($dir);
 		} catch (NotFoundException $e) {
-			$this->log("MKCOL NFE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+			$this->log("MKCOL NotFoundException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Directory not found'));
+			throw $e;
 		} catch (AlreadyExistsException $e) {
-			$this->log("MKCOL AEE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_ALREADY_EXISTS), self::SMB_ERR_ALREADY_EXISTS);
+			$this->log("MKCOL AlreadyExistsException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_ALREADY_EXISTS), self::SMB_ERR_ALREADY_EXISTS);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Directory already exist'));
+			throw $e;
 		} catch (ForbiddenException $e) {
-			$this->log("MKCOL FBE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+			$this->log("MKCOL ForbiddenException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+			throw $e;
 		} catch (\Exception $e) {
-			$this->log("MKCOL failed: " . print_r($e, true));
-			throw new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+			$this->log("MKCOL general exception: " . print_r($e, true));
+			$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Failed'));
+			throw $e;
 		}
 
 		return true;
@@ -494,33 +512,49 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 					$info = $this->deleteAllContent($path);
 				}
 			} catch (NotFoundException $e) {
-				$this->log("RMDIR NFE: " . print_r($e, true));
-				throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+				$this->log("Remove directory NotFoundException: " . print_r($e, true));
+				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Directory not found'));
+				throw $e;
 			} catch (InvalidTypeException $e) {
-				$this->log("RMDIR ITE: " . print_r($e, true));
-				throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
+				$this->log("Remove directory InvalidTypeException: " . print_r($e, true));
+				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
+				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Invalid Type'));
+				throw $e;
 			} catch (ForbiddenException $e) {
-				$this->log("RMDIR FBE: " . print_r($e, true));
-				throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+				$this->log("Remove directory ForbiddenException: " . print_r($e, true));
+				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+				throw $e;
 			} catch (\Exception $e) {
-				$this->log("RMDIR failed: " . print_r($e, true));
-				throw new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+				$this->log("Remove directory general exception: " . print_r($e, true));
+				$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Deletion failed'));
+				throw $e;
 			}
 		} else {
 			try {
 				$info = $this->smb_share->del($path);
 			} catch (NotFoundException $e) {
-				$this->log("RMFILE NFE: " . print_r($e, true));
-				throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+				$this->log("Remove file NotFoundException: " . print_r($e, true));
+				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not found'));
+				throw $e;
 			} catch (InvalidTypeException $e) {
-				$this->log("RMFILE ITE: " . print_r($e, true));
-				throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
+				$this->log("Remove file InvalidTypeException: " . print_r($e, true));
+				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
+				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Invalid type'));
+				throw $e;
 			} catch (ForbiddenException $e) {
-				$this->log("RMFILE FBE: " . print_r($e, true));
-				throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+				$this->log("Remove file ForbiddenException: " . print_r($e, true));
+				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+				throw $e;
 			} catch (\Exception $e) {
-				$this->log("DEL failed: " . print_r($e, true));
-				throw new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+				$this->log("Remove file general exception, failed: " . print_r($e, true));
+				$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Deletion failed'));
+				throw $e;
 			}
 		}
 
@@ -569,17 +603,25 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		try {
 			$this->smb_share->rename($src_path, $dst_path);
 		} catch (NotFoundException $e) {
-			$this->log("MOVE NFE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+			$this->log("Move NotFoundException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not found'));
+			throw $e;
 		} catch (AlreadyExistsException $e) {
-			$this->log("MOVE AEE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_ALREADY_EXISTS), self::SMB_ERR_ALREADY_EXISTS);
+			$this->log("Move AlreadyExistsException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_ALREADY_EXISTS), self::SMB_ERR_ALREADY_EXISTS);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Already exist'));
+			throw $e;
 		} catch (ForbiddenException $e) {
-			$this->log("MOVE FBE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+			$this->log("Move ForbiddenException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+			throw $e;
 		} catch (\Exception $e) {
-			$this->log("MOVE failed: " . print_r($e, true));
-			throw new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+			$this->log("Move general exception, failed: " . print_r($e, true));
+			$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Moving failed'));
+			throw $e;
 		}
 
 		return true;
@@ -604,7 +646,9 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		if ($fresult !== FALSE) {
 			return $result;
 		} else {
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_TMP), self::SMB_ERR_TMP);
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_TMP), self::SMB_ERR_TMP);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Issues with TMP directory'));
+			throw $e;
 		}
 	}
 
@@ -624,17 +668,25 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		try {
 			$this->smb_share->put($filename, $path);
 		} catch (NotFoundException $e) {
-			$this->log("PUT_FILE NFE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+			$this->log("put_file NotFoundException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not found'));
+			throw $e;
 		} catch (InvalidTypeException $e) {
-			$this->log("PUT_FILE ITE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
+			$this->log("put_file InvalidTypeException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Invalid type'));
+			throw $e;
 		} catch (ForbiddenException $e) {
-			$this->log("PUT_FILE FBE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+			$this->log("put_file ForbiddenException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FORBIDDEN), self::SMB_ERR_FORBIDDEN);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Forbidden'));
+			throw $e;
 		} catch (\Exception $e) {
-			$this->log("PUT_FILE failed: " . print_r($e, true));
-			throw new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+			$this->log("put_file general exception, failed: " . print_r($e, true));
+			$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Uploading failed'));
+			throw $e;
 		}
 
 		return true;
@@ -661,7 +713,9 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 			if ($buffer !== FALSE) {
 				return $result;
 			} else {
-				throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_TMP), self::SMB_ERR_TMP);
+				$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_TMP), self::SMB_ERR_TMP);
+				$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Issues with TMP directory'));
+				throw $e;
 			}
 		} else {
 			return $result;
@@ -684,14 +738,20 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		try {
 			$this->smb_share->get($srcpath, $localpath);
 		} catch (NotFoundException $e) {
-			$this->log("GET_FILE NFE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+			$this->log("get_file NotFoundException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_NOTFOUND), self::SMB_ERR_NOTFOUND);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not found'));
+			throw $e;
 		} catch (InvalidTypeException $e) {
-			$this->log("GET_FILE ITE: " . print_r($e, true));
-			throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
+			$this->log("get_file InvalidTypeException: " . print_r($e, true));
+			$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_INV_TYPE), self::SMB_ERR_INV_TYPE);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Invalid type'));
+			throw $e;
 		} catch (\Exception $e) {
-			$this->log("GET_FILE failed: " . print_r($e, true));
-			throw new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+			$this->log("get_file general exception, failed: " . print_r($e, true));
+			$e = new BackendException($e->getMessage(), self::SMB_ERR_INTERNAL);
+			$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Failed to get file'));
+			throw $e;
 		}
 
 		return true;
@@ -715,7 +775,10 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	 */
 	public function copy_file($src_path, $dst_path, $overwrite = false)
 	{
-		throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
+		// TODO Fix or remove me
+		$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
+		$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not implemented'));
+		throw $e;
 	}
 
 	/**
@@ -736,7 +799,10 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	 */
 	public function copy_coll($src_path, $dst_path, $overwrite = false)
 	{
-		throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
+		// TODO Fix or remove me
+		$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
+		$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not implemented'));
+		throw $e;
 	}
 
 	/**
@@ -758,7 +824,9 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		}
 
 		$this->log('gpi: wrong response from ls');
-		throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FAILED_DEPENDENCY), self::SMB_ERR_FAILED_DEPENDENCY);
+		$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_FAILED_DEPENDENCY), self::SMB_ERR_FAILED_DEPENDENCY);
+		$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Request failed'));
+		throw $e;
 	}
 
 	/**
@@ -769,7 +837,10 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	 */
 	public function options()
 	{
-		throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
+		// TODO Fix or remove me
+		$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
+		$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not implemented'));
+		throw $e;
 	}
 
 	/**
@@ -785,7 +856,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		try {
 			$info = $this->smb_share->stat($path);
 		} catch (\Exception $e) {
-			$this->log("IS_FILE failed: " . print_r($e, true));
+			$this->log("is_file failed: " . print_r($e, true));
 			return false;
 		}
 
@@ -805,7 +876,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		try {
 			$info = $this->smb_share->stat($path);
 		} catch (\Exception $e) {
-			$this->log("IS_DIR failed: " . print_r($e, true));
+			$this->log("is_dir failed: " . print_r($e, true));
 			return false;
 		}
 
@@ -825,7 +896,7 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 		try {
 			$info = $this->smb_share->stat($path);
 		} catch (\Exception $e) {
-			$this->log("EXISTS failed: " . print_r($e, true));
+			$this->log("exist failed: " . print_r($e, true));
 			return false;
 		}
 
@@ -850,7 +921,10 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	 */
 	private function copy($src_path, $dst_path, $overwrite, $coll)
 	{
-		throw new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
+		// TODO Fix or remove me
+		$e = new BackendException($this->parseErrorCodeToMessage(self::SMB_ERR_UNIMPLEMENTED), self::SMB_ERR_UNIMPLEMENTED);
+		$e->setTitle(dgettext('plugin_filesbackendSMB', 'Files SMB Backend: Not implemented'));
+		throw $e;
 	}
 
 	/**
@@ -863,7 +937,6 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 	private function parseErrorCodeToMessage($error_code)
 	{
 		$error = intval($error_code);
-
 		$msg = dgettext('plugin_filesbackendSMB', 'Unknown error');
 
 		switch ($error) {
@@ -871,40 +944,41 @@ class Backend extends AbstractBackend implements iFeatureQuota, iFeatureVersionI
 				$msg = dgettext('plugin_filesbackendSMB', 'Unauthorized. Wrong username or password.');
 				break;
 			case self::SMB_ERR_UNREACHABLE:
-				$msg = dgettext('plugin_filesbackendSMB', 'File-server is not reachable. Wrong IP entered?');
+				$msg = dgettext('plugin_filesbackendSMB', 'File server is not reachable. Please verify the connection.');
 				break;
 			case self::SMB_ERR_FORBIDDEN:
-				$msg = dgettext('plugin_filesbackendSMB', 'You don\'t have enough permissions for this operation.');
+				$msg = dgettext('plugin_filesbackendSMB', 'You don\'t have enough permissions to view this file or folder.');
 				break;
 			case self::SMB_ERR_NOTFOUND:
-				$msg = dgettext('plugin_filesbackendSMB', 'File is not available any more.');
+				$msg = dgettext('plugin_filesbackendSMB', 'The file or folder is not available anymore.');
 				break;
 			case self::SMB_ERR_TIMEOUT:
-				$msg = dgettext('plugin_filesbackendSMB', 'Connection to server timed out. Retry later.');
+				$msg = dgettext('plugin_filesbackendSMB', 'Connection to the file server timed out. Please check again later.');
 				break;
 			case self::SMB_ERR_FAILED_DEPENDENCY:
-				$msg = dgettext('plugin_filesbackendSMB', 'The request failed due to failure of a previous request.');
+				$msg = dgettext('plugin_filesbackendSMB', 'The request failed due to failure of a previous request. Please contact your system administrator.');
 				break;
 			case self::SMB_ERR_INTERNAL:
-				$msg = dgettext('plugin_filesbackendSMB', 'File-server encountered a problem. Wrong IP entered?');
-				break; // this comes most likely from a wrong ip
+				// This is a general error, might be thrown due to a wrong IP, but we don't know.
+				$msg = dgettext('plugin_filesbackendSMB', 'The file server encountered an internal problem. Please contact your system administrator');
+				break;
 			case self::SMB_ERR_TMP:
-				$msg = dgettext('plugin_filesbackendSMB', 'Could not write to temporary directory. Contact the server administrator.');
+				$msg = dgettext('plugin_filesbackendSMB', 'We could not write to temporary directory. Please contact your system administrator.');
 				break;
 			case self::SMB_ERR_FEATURES:
-				$msg = dgettext('plugin_filesbackendSMB', 'Could not retrieve list of server features. Contact the server administrator.');
+				$msg = dgettext('plugin_filesbackendSMB', 'We could not retrieve list of server features. Please contact the server administrator.');
 				break;
 			case self::SMB_ERR_NO_SMB_LIB:
-				$msg = dgettext('plugin_filesbackendSMB', 'libsmbclient-php is not available. Contact your system administrator.');
+				$msg = dgettext('plugin_filesbackendSMB', 'libsmbclient-php is not available. Please contact your system administrator.');
 				break;
 			case self::SMB_ERR_INV_TYPE:
-				$msg = dgettext('plugin_filesbackendSMB', 'Destination is not a valid folder!');
+				$msg = dgettext('plugin_filesbackendSMB', 'Destination is not valid. Please select a valid folder.');
 				break;
 			case self::SMB_ERR_ALREADY_EXISTS:
-				$msg = dgettext('plugin_filesbackendSMB', 'File/Folder already exists!');
+				$msg = dgettext('plugin_filesbackendSMB', 'File or folder already exists.');
 				break;
 			case self::SMB_ERR_UNIMPLEMENTED:
-				$msg = dgettext('plugin_filesbackendSMB', 'Function is not implemented in this backend.');
+				$msg = dgettext('plugin_filesbackendSMB', 'This function is not yet implemented.');
 				break;
 		}
 
