@@ -322,6 +322,19 @@ Ext.namespace('Zarafa.widgets.folderwidgets');
  * outside of WebApp.
  */
 Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.folderwidgets.AbstractFolderWidget, {
+	/**
+	 * The folder which was selected by the user
+	 * @property
+	 * @type Zarafa.hierarchy.data.MAPIFolderRecord
+	 */
+	folder : undefined,
+
+	/**
+	 * 'entryid' of folder which was selected by the user
+	 * @property
+	 * @type String
+	 */
+	folderId : undefined,
 
 	/**
 	 * @constructor
@@ -343,6 +356,7 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 				cls: 'k-appointmentwidget',
 				store: store,
 				hideHeaders: true,
+				ref : 'appointmentsGrid',
 				loadMask: {
 					msg: _('Loading appointments...')
 				},
@@ -351,7 +365,7 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 				}),
 				viewConfig: {
 					deferEmptyText: false,
-					emptyText: '<div class="emptytext">' + _('No appointments') + '</div>',
+					emptyText: '<div class="emptytext">' + _("Please select a calendar via widget settings") + '</div>',
 					forceFit: true,
 					enableRowBody: true,
 					rowSelectorDepth: 15,
@@ -380,6 +394,7 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 		};
 
 		Zarafa.widgets.folderwidgets.AppointmentsWidget.superclass.constructor.call(this, config);
+		this.folderId = this.get('folderId');
 	},
 
 	/**
@@ -403,9 +418,209 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 				scope: this
 			},
 			plugins: ['zarafa.numberspinner']
+		},{
+			xtype: 'zarafa.calendarfolderselectionlink',
+			folder: this.folder,
+			fieldLabel: _('Calendar'),
+			name: 'Calendar',
+			listeners: {
+				'folderupdate': this.onUpdateFolder,
+				scope: this
+			}
 		}];
 	},
 
+	/**
+	 * Initialize the event handlers for the {@link #store} and {@link Zarafa.hierarchy.data.HierarchyStore HierarchyStore}.
+	 * @protected
+	 */
+	initEvents: function () {
+		Zarafa.widgets.folderwidgets.AppointmentsWidget.superclass.initEvents.apply(this, arguments);
+
+		// set handlers to update widget state on remove of folder from hierarchy.
+		var hierarchyStore = container.getHierarchyStore();
+		this.mon(hierarchyStore, {
+			'remove': this.onSharedStoreRemove,
+			'removeFolder': this.onSharedStoreRemove,
+			scope: this
+		});
+
+		// Wait for the store to be loaded, so we can activate
+		// the filter task and set empty text if no appointments available.
+		this.mon(this.store, 'load', this.onStoreLoad, this, { single: true });
+		this.mon(this.store, 'exception', this.onStoreException, this);
+	},
+
+	/**
+	 * Handler for {@link #store} for {@link Ext.data.Store#load load} event.
+	 * This will call {@link #startFilterTask} and {@link #setEmptytext} after the {@link #store} load.
+	 * @private
+	 */
+	onStoreLoad : function()
+	{
+		this.startFilterTask();
+		this.setEmptytext();
+	},
+
+	/**
+	 * Handler for {@link #store} for {@link Ext.data.Store#exception exception} event.
+	 * This will remove all records from store and set empty text as error message received from php side.
+	 *
+	 * @param {Misc} misc See {@link Ext.data.DataProxy}#{@link Ext.data.DataProxy#exception exception}
+	 * for description.
+	 * @private
+	 */
+	onStoreException: function(proxy, type, action, options, response, args)
+	{
+		var emptyText;
+		if (response && response.error) {
+			var errObj = response.error;
+
+			if (errObj.info && errObj.info.display_message) {
+				emptyText = String.format(_("{0}"), errObj.info.display_message);
+			}
+		}
+
+		// Empty store so that we can show error message.
+		this.appointmentsGrid.getStore().removeAll();
+		this.setEmptytext(emptyText);
+	},
+
+	/**
+	 * Load the stored calendar folder and retrieve the records.
+	 * @param {Zarafa.hierarchy.data.HierarchyStore} hierarchyStore The store which fired the event
+	 * @private
+	 */
+	onHierarchyLoad: function (hierarchyStore)
+	{
+		if (Ext.isEmpty(this.folderId)) {
+			return;
+		}
+
+		this.folder = hierarchyStore.getFolder(this.folderId);
+		var folderReadRight = Zarafa.core.mapi.Rights.RIGHTS_READ_ANY;
+		if (Ext.isEmpty(this.folder) ||
+			(this.folder.get('rights') & folderReadRight) !== folderReadRight) {
+			// Reset when there is folderId and we can't find folder
+			// or folder has not 'RIGHTS_FOLDER_VISIBLE' rights.
+			// So, we need to reset the state.
+			this.resetWidget();
+			return;
+		}
+
+		this.setWidgetTitle(this.folder);
+		this.reloadStore();
+	},
+
+	/**
+	 * Reset when previously selected folder is not found (e.g. saved states will be cleared on reset settings of webapp).
+	 * This will be called from {@link Zarafa.widgets.folderwidgets.AbstractFolderWidget#onHierarchyLoad onHierarchyLoad}
+	 * when folder is not found and when the 'remove' or 'removeFolder' event fired for hierarchy store.
+	 */
+	resetWidget : function()
+	{
+		this.folder = undefined;
+		this.folderId = undefined;
+		this.set("folderId", undefined);
+		this.appointmentsGrid.getStore().removeAll();
+	},
+
+	/**
+	 * This method will set name of this widget. 
+	 * If folder is not given, it will set default title otherwise it will prepare
+	 * title for widget as per folder given and apply it.
+	 *
+	 * @param {Zarafa.hierarchy.data.MAPIFolderRecord} folder folder which is selected to show appointments from.
+	 * @private
+	 */
+	setWidgetTitle : function(folder)
+	{
+		var title = _('Upcoming Appointments');
+		
+		if (folder) {
+			var folderStore = folder.getMAPIStore();
+			var isOwnStore = folderStore.isDefaultStore();
+			var isDefaultFolder = folder.isDefaultFolder();
+
+			var ownerName = folderStore.get('display_name');
+			var folderName = folder.get('display_name');
+			
+			// Do not show ownername for own store folder.
+			// And don't change title for default calendar folder of own store.
+			if (!(isOwnStore && isDefaultFolder)) {
+				if (isOwnStore) {
+					title = String.format(_('Appointments of {0}'), folderName);
+				} else {
+					title = String.format(_('Appointments of {0} - {1}'), folderName, ownerName);
+				}
+			}
+		}
+
+		this.setTitle(title);
+	},
+
+	/**
+	 * This method will set empty text message of this widget.
+	 * If the emptyText param is not provided then it will set 'No appointments' message
+	 * when no appointments are available.
+	 * Or if {@link #folder} has no value (no folder is selected currently) then
+	 * this will display a message to select folder.
+	 *
+	 * @param {String} emptyText which needs to be set as empty text of grid view.
+	 */
+	setEmptytext : function(emptyText)
+	{
+		var gridView = this.appointmentsGrid.getView();
+
+		if (Ext.isEmpty(emptyText)) {
+			emptyText = this.folder ? _('No appointments') : _("Please select a calendar via widget settings");
+		}
+
+		gridView.emptyText = '<div class="emptytext">'+ emptyText +'</div>';
+		gridView.refresh();
+	},
+
+	/**
+	 * Event handler for 'remove' and 'removeFolder' events of {@link Zarafa.hierarchy.data.HierarchyStore Hierarchy}
+	 * This will reset widget if state folder of this widget gets deleted.
+	 * 
+	 * @param {Zarafa.hierarchy.data.HierarchyStore} store hierarchy store after removing record.
+	 * @param {Zarafa.hierarchy.data.MAPIStoreRecord} record The record which is removed
+	 * @param {Number} totalRecords total number of records in store.
+	 */
+	onSharedStoreRemove : function(store, record, totalRecords)
+	{
+		var stateFolderId = this.get('folderId');
+		if (!Ext.isEmpty(stateFolderId)) {
+			var stateFolder = store.getFolder(stateFolderId);
+
+			// If deleted folder is state folder or closed shared store includes
+			// state folder then reset this widget.
+			if (Ext.isEmpty(stateFolder)) {
+				this.resetWidget();
+				this.setEmptytext();
+			}
+		}
+	},
+
+	/**
+	 * Event handler for 'folderupdate' event.
+	 * This will update the {@link #folder} , save the folder entryid in state,
+	 * set title of this widget and reload the state with updated folder.
+	 * 
+	 * @param {Zarafa.hierarchy.data.MAPIFolderRecord} folder folder which is selected to show appointments from.
+	 * @private
+	 */
+	onUpdateFolder: function (folder)
+	{
+		this.folder = folder;
+		this.folderId = folder.get('entryid');
+		this.set("folderId", this.folderId);
+		this.setWidgetTitle(folder);
+		this.reloadStore();
+		this.setEmptytext();
+	},
+
 	/**
 	 * Event handler which is fired when 'Number of Days' field in the Configuration dialog
 	 * has been changed. This will update the corresponding option in the settings.
@@ -420,19 +635,6 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 		this.reloadStore();
 	},
 
-	/**
-	 * Initialize the event handlers for the {@link #store} and {@link Zarafa.hierarchy.data.HierarchyStore Hierarchy}.
-	 * @protected
-	 */
-	initEvents: function ()
-	{
-		Zarafa.widgets.folderwidgets.AppointmentsWidget.superclass.initEvents.apply(this, arguments);
-
-		// Wait for the store to be loaded, so we can activate
-		// the filter task.
-		this.mon(this.store, 'load', this.startFilterTask, this, {single: true});
-	},
-
 	/**
 	* Starts a filter task for the store. Will make sure that the filter is updated at
 	* every 30 seconds so old appointments will be filtered out.
@@ -466,6 +668,7 @@ Zarafa.widgets.folderwidgets.AppointmentsWidget = Ext.extend(Zarafa.widgets.fold
 		this.store.load({
 			folder: this.folder,
 			params: {
+				ignoreException: true,
 				restriction: {
 					startdate: startdate,
 					duedate: duedate
@@ -980,3 +1183,206 @@ Zarafa.onReady(function () {
 		widgetConstructor : Zarafa.widgets.folderwidgets.TasksWidget
 	}));
 });
+Ext.namespace('Zarafa.widgets.folderwidgets');
+
+/**
+ * @class Zarafa.widgets.folderwidgets.AppointmentsWidget
+ * @extends Zarafa.widgets.folderwidgets.AbstractFolderWidget
+ *
+ * Widget that displays the appointments for today, from the default
+ * calendar.  It only displays appointments that occur on or after the
+ * current time, so outdated information is never shown.
+ *
+ * Reload time is configurable per instance of the
+ * widget (keys: 'reloadinterval', default 5 minutes).  These values are in
+ * saved in miliseconds but displayed in seconds. The reload
+ * interval is how often the calendar is fully reloaded from the
+ * server, to show records that were added to the folder
+ * outside of WebApp.
+ */
+Zarafa.widgets.folderwidgets.DatepickerWidget = Ext.extend(Zarafa.widgets.folderwidgets.AbstractFolderWidget, {
+
+	/**
+	 * @constructor
+	 * @param {Object} config Configuration object
+	 */
+	constructor: function (config)
+	{
+		config = config || {};
+
+		var store = new Zarafa.calendar.AppointmentStore();
+
+		Ext.applyIf(config, {
+			autoScroll: false,
+			autoHeight: true,
+			layout: 'hbox',
+			folderType: 'calendar',
+			store: store,
+			items: [{
+				xtype: 'zarafa.datepicker',
+				ref: 'datePicker',
+				hideLabel: true,
+				showWeekNumber: true,
+				showToday: true,
+				width: '100%',
+				listeners: {
+					scope: this
+				},
+				handler: this.datePickerHandler
+			}]
+		});
+
+
+		Zarafa.widgets.folderwidgets.DatepickerWidget.superclass.constructor.call(this, config);
+
+		// FIXME Workaround for KW-1812 (not rendering busy days bold when coming back to current month)
+		Ext.TaskMgr.start({
+			run: this.updateFilter,
+			interval: 2000, // every 2 seconds
+			scope: this
+		});
+	},
+
+	/**
+	 * FIXME React on clicks: switch to calendar-view + selected date
+	 * Event handler which is triggered when user clicks on any date
+	 * @param {DatePicker} DatePicker object
+	 * @param {Date} Date that was clicker
+	 * @private
+	 */
+	datePickerHandler: Ext.emptyFn,
+
+	/**
+	 * Update the DatePicker when the calender is changed
+	 * @private
+	 */
+	updateFilter: function ()
+	{
+		if (this.datePicker) {
+			this.datePicker.show();
+		}
+
+		return Zarafa.widgets.folderwidgets.DatepickerWidget.superclass.updateFilter.apply(this, arguments);
+	}
+});
+
+Zarafa.onReady(function () {
+	container.registerWidget(new Zarafa.core.ui.widget.WidgetMetaData({
+		name: 'datepicker',
+		displayName: _('Datepicker'),
+		widgetConstructor: Zarafa.widgets.folderwidgets.DatepickerWidget
+	}));
+});
+Ext.namespace('Zarafa.widgets.folderwidgets');
+
+/**
+ * @class Zarafa.widgets.folderwidgets.CalendarFolderSelectionLink
+ * @extends Ext.BoxComponent
+ * @xtype zarafa.calendarfolderselectionlink
+ *
+ * This will show the currently selected {@link #folder} to the user, and allows
+ * the user to select the desired folder to view appointments from.
+ */
+Zarafa.widgets.folderwidgets.CalendarFolderSelectionLink = Ext.extend(Ext.BoxComponent, {
+	/**
+	 * @cfg {String} fieldLabel The label which must be applied to template
+	 * as a prefix to the list of attachments.
+	 */
+	emptyText :_('Select one...'),
+
+	/**
+	 * The folder which was selected by the user
+	 * @property
+	 * @type Zarafa.hierarchy.data.MAPIFolderRecord
+	 */
+	folder : undefined,
+
+	/**
+	 * @constructor
+	 * @param {Object} config configuration object.
+	 */
+	constructor : function(config)
+	{
+		config = config || {};
+
+		Ext.applyIf(config,{
+			xtype: 'zarafa.calendarfolderselectionlink',
+			border : false,
+			autoScroll :true,
+			anchor : '100%',
+			tpl : new Ext.XTemplate(
+				'<div class="zarafa-folder-link">' +
+					'<tpl if="!Ext.isEmpty(values.display_name)">' +
+						'&quot;{display_name:htmlEncode}&quot;' +
+					'</tpl>' +
+					'<tpl if="Ext.isEmpty(values.display_name)">' +
+						'&quot;' + _('Unnamed folder') + '&quot;' +
+					'</tpl>' +
+				'</div>',
+				{
+					compiled : true
+				}
+			)
+		});
+
+		Zarafa.widgets.folderwidgets.CalendarFolderSelectionLink.superclass.constructor.call(this, config);
+	},
+
+	/**
+	 * This function is called after the component has been rendered.
+	 * This will update {@link Zarafa.widgets.folderwidgets.CalendarFolderSelectionLink} with selected folder
+	 * and will register {@link #onClick} event handler.
+	 * @private
+	 */
+	afterRender : function()
+	{
+		Zarafa.widgets.folderwidgets.CalendarFolderSelectionLink.superclass.afterRender.apply(this, arguments);
+
+		this.update();
+		this.mon(this.getEl(), 'click', this.onClick, this);
+	},
+
+	/**
+	 * Called when user clicks on a {@link Zarafa.widgets.folderwidgets.CalendarFolderSelectionLink}
+	 * It opens hierarchy folder selection dialog containing all calendar folders.
+	 * @param {Ext.DataView} dataView Reference to this object
+	 * @param {Number} index The index of the target node
+	 * @param {HTMLElement} node The target node
+	 * @param {Ext.EventObject} evt The mouse event
+ 	 * @protected
+	 */
+	onClick : function(dataView, index, node, evt)
+	{
+		var defaultCalendar = container.getHierarchyStore().getDefaultFolder('calendar');
+		var folder = Ext.isEmpty(this.folder) ? defaultCalendar : this.folder;
+		Zarafa.hierarchy.Actions.openFolderSelectionContent({
+			folder : folder,
+			hideTodoList: true,
+			IPMFilter: 'IPF.Appointment',
+			callback : this.update,
+			scope : this,
+			modal : true
+		});
+	},
+
+	/**
+	 * Update the contents of this dataview, this will apply the {@link #tpl} for
+	 * the {@link #folder}.
+	 * @param {Zarafa.hierarchy.data.MAPIFolderRecord} folder The folder to show
+	 */
+	update : function(folder)
+	{
+		// Avoid 'folderupdate' for the first time when this component loads.
+		if (folder) {
+			this.folder = folder;
+			this.fireEvent('folderupdate', folder);
+		} else {
+			folder = this.folder;
+		}
+
+ 		var data = folder ? folder.data : { display_name : this.emptyText };
+		Zarafa.widgets.folderwidgets.CalendarFolderSelectionLink.superclass.update.call(this, this.tpl.apply(data));
+	}
+});
+
+Ext.reg('zarafa.calendarfolderselectionlink', Zarafa.widgets.folderwidgets.CalendarFolderSelectionLink);
