@@ -485,9 +485,11 @@ Zarafa.plugins.quill.ui.QuillEditor = Ext.extend(Ext.Container, {
 		Size.whitelist = formatting.fontSize;
 		quill.register(Size, true);
 
-		// Added custom font families
+		// Remove default font families 
 		var Font = quill.import('attributors/style/font');
-		Font.whitelist = formatting.fontFamilies;
+		// We need to remove the default values because the whitelist accepts 
+		// only single values and not fallback fonts.
+		Font.whitelist = undefined;
 		quill.register(Font, true);
 
 		// customize the p tag.
@@ -589,19 +591,19 @@ Zarafa.plugins.quill.ui.QuillEditor = Ext.extend(Ext.Container, {
 		var fontType = container.getSettingsModel().get('zarafa/v1/main/default_font').split(',')[0];
 		switch (fontType) {
 			case 'courier new':
-				fontType = 'Courier New';
+				fontType = 'courier new,courier';
 				break;
 			case 'times new roman':
-				fontType = 'Times New Roman';
+				fontType = 'times new roman,times';
 				break;
 			case 'tahoma':
-				fontType = 'Tahoma';
+				fontType = 'tahoma,arial,helvetica,sans-serif';
 				break;
 			case 'verdana':
-				fontType = 'Verdana';
+				fontType = 'verdana,geneva';
 				break;
 			default:
-				fontType = 'Arial';
+				fontType = 'arial,helvetica,sans-serif';
 		}
 
 		return {
@@ -634,9 +636,6 @@ Zarafa.plugins.quill.ui.QuillEditor = Ext.extend(Ext.Container, {
 		var defaultFormatting = this.getDefaultFontFormatting();
 		this.editor.format('size', defaultFormatting.fontSize, 'user');
 		this.editor.format('font', defaultFormatting.fontFamily, 'user');
-		// FIXME : We have to explicitly format the editor contents with defined margin
-		// Find proper way for formatting
-		this.editor.formatLine(0, this.editor.getLength(), 'margin', '0px 5px');
 
 		// As the 'code-block' button has been removed, any text wrapped in <pre> tag
 		// should be displayed without the code-block. Hence, we set the 'code-block' attribute
