@@ -1003,25 +1003,27 @@ Zarafa.widgets.quickitems.QuickMailWidget = Ext.extend(Zarafa.widgets.quickitems
 						style: 'padding-bottom: 2px'
 					},
 					items : [{
-						xtype: 'zarafa.compositefield',
+						xtype: 'zarafa.resizablecompositefield',
 						hideLabel: true,
 						anchor: '100%',
 						autoHeight: true,
 						items: [{
 							xtype: 'label',
 							width: 20,
+							autoHeight: true,
 							text: _('To') + ':'
 						},{
 							xtype: 'zarafa.recipientfield',
 							ref: '../toRecipientField',
 							flex: 1,
-							height: 30,
+							autoHeight: true,
 							defaultRecipientType: Zarafa.core.mapi.RecipientType.MAPI_TO
 						}]			
 					},{
 						xtype: 'zarafa.compositefield',
 						hideLabel: true,
 						anchor: '100%',
+						autoHeight: true,
 						items: [{
 							xtype: 'textfield',
 							flex: 1,
@@ -1294,7 +1296,7 @@ Zarafa.widgets.quickitems.QuickTaskWidget = Ext.extend(Zarafa.widgets.quickitems
 				layout : 'fit',
 				items : [{
 					xtype : 'form',
-					ref : 'formPanel',
+					ref : '../formPanel',
 					layout: {
 						type: 'vbox',
 						align: 'stretch'
@@ -1327,7 +1329,7 @@ Zarafa.widgets.quickitems.QuickTaskWidget = Ext.extend(Zarafa.widgets.quickitems
 						items: [{
 						},{
 							xtype: 'datefield',
-							ref: '../../dueDateField',
+							ref: '../dueDateField',
 							emptyText : _('End date') + ': ' + _('none'),
 							flex: 1,
 							name: 'commonend',
@@ -1342,7 +1344,7 @@ Zarafa.widgets.quickitems.QuickTaskWidget = Ext.extend(Zarafa.widgets.quickitems
 						}]
 					},{
 						xtype: 'zarafa.editorfield',
-						ref: '../editorField',
+						ref: 'editorField',
 						htmlName : 'html_body',
 						plaintextName : 'body',
 						hideLabel: true,
@@ -1385,11 +1387,11 @@ Zarafa.widgets.quickitems.QuickTaskWidget = Ext.extend(Zarafa.widgets.quickitems
 	onDueDateChange : function(field, newValue, oldValue)
 	{
 		if (Ext.isDate(newValue)) {
-			this.wrap.record.set(field.name, newValue.clone());
-			this.wrap.record.set(field.utcname, newValue.toUTC());
+			this.record.set(field.name, newValue.clone());
+			this.record.set(field.utcname, newValue.fromUTC());
 		} else {
-			this.wrap.record.set(field.name, null);
-			this.wrap.record.set(field.utcname, null);
+			this.record.set(field.name, null);
+			this.record.set(field.utcname, null);
 		}
 	},
 
@@ -1416,7 +1418,7 @@ Zarafa.widgets.quickitems.QuickTaskWidget = Ext.extend(Zarafa.widgets.quickitems
 	 */
 	update : function(record, contentReset)
 	{
-		this.wrap.formPanel.getForm().loadRecord(record);
+		this.formPanel.getForm().loadRecord(record);
 	},
 
 	/**
@@ -1428,9 +1430,9 @@ Zarafa.widgets.quickitems.QuickTaskWidget = Ext.extend(Zarafa.widgets.quickitems
 	updateRecord : function(record)
 	{
 		record.beginEdit();
-		this.wrap.formPanel.getForm().updateRecord(record);
-		this.onDueDateChange(this.wrap.dueDateField, this.wrap.dueDateField.getValue());
-		this.onBodyChange(this.wrap.editorField, this.wrap.editorField.getValue());
+		this.formPanel.getForm().updateRecord(record);
+		this.onDueDateChange(this.formPanel.dueDateField, this.formPanel.dueDateField.getValue());
+		this.onBodyChange(this.formPanel.editorField, this.formPanel.editorField.getValue());
 		record.endEdit();
 	}
 });
