@@ -783,6 +783,7 @@
 				$properties["account"] = PR_ACCOUNT;
 				$properties["address_type"] = PR_ADDRTYPE;
 				$properties["title"] = PR_TITLE;
+				$properties["company_name"] = PR_COMPANY_NAME;
 				$properties["object_type"] = PR_OBJECT_TYPE;
 				$properties["search_key"] = PR_SEARCH_KEY;
 				$properties["office_telephone_number"] = PR_OFFICE_TELEPHONE_NUMBER;
@@ -1029,7 +1030,8 @@
 
 				// Conversation properties
 				$properties["conversation_topic"] = PR_CONVERSATION_TOPIC;
-
+				$properties["conversation_index"] = PR_CONVERSATION_INDEX;
+				
 				// Allowing to hook in and add more properties
 				$GLOBALS['PluginManager']->triggerHook("server.core.properties.mailproperties", array(
 					'properties' =>& $properties
@@ -1065,7 +1067,7 @@
 			unset($properties['meetingtype']);
 			unset($properties['goid']);
 			unset($properties['goid2']);
-
+			unset($properties["conversation_index"]);
 			return $properties;
 		}
 
