@@ -268,6 +268,7 @@
 	 */
 	function browserDependingHTTPHeaderEncode($input)
 	{
+		$input = preg_replace("/\r|\n/", "", $input);
 		if(!isIE11() && !isEdge()) {
 			return $input;
 		} else {
@@ -748,4 +749,18 @@
 
 		return true;
 	}
+
+	/**
+	 * Function returns the IP address of the client.
+	 * 
+	 * @return String The IP address of the client.
+	 */
+	function getClientIPAddress() {
+		// Here, there is a scenario where the server is behind a proxy, when that 
+		// happens, 'REMOTE_ADDR' will not return the real IP, there is another variable
+		// 'HTTP_X_FORWARDED_FOR' which is set by a proxy server. But the risk in using that 
+		// is that it can be easily forged. 'REMOTE_ADDR' is the only reliable thing
+		// as it is nearly impossible to be altered.
+		return $_SERVER['REMOTE_ADDR'];
+	}
 ?>
